
COLORS={}
# Reset
COLORS["reset"]= "\033[0m"       # Text Reset

# Regular Colors
COLORS["black"]= "\033[0;30m"        # Black
COLORS["red"]= "\033[0;31m"          # Red
COLORS["green"]= "\033[0;32m"        # Green
COLORS["yellow"]= "\033[0;33m"       # Yellow
COLORS["blue"]= "\033[0;34m"         # Blue
COLORS["purple"]= "\033[0;35m"       # Purple
COLORS["cyan"]= "\033[0;36m"         # Cyan
COLORS["white"]= "\033[0;37m"        # White

# Bold
COLORS["boldBlack"]= "\033[1;30m"       # Black
COLORS["boldRed"]= "\033[1;31m"         # Red
COLORS["boldGreen"]= "\033[1;32m"       # Green
COLORS["boldYellow"]= "\033[1;33m"      # Yellow
COLORS["boldBlue"]= "\033[1;34m"        # Blue
COLORS["boldPurple"]= "\033[1;35m"      # Purple
COLORS["boldCyan"]= "\033[1;36m"        # Cyan
COLORS["boldWhite"]= "\033[1;37m"       # White

# Underline
COLORS["underlineBlack"]= "\033[4;30m"       # Black
COLORS["underlineRed"]= "\033[4;31m"         # Red
COLORS["underlineGreen"]= "\033[4;32m"       # Green
COLORS["underlineYellow"]= "\033[4;33m"      # Yellow
COLORS["underlineBlue"]= "\033[4;34m"        # Blue
COLORS["underlinePurple"]= "\033[4;35m"      # Purple
COLORS["underlineCyan"]= "\033[4;36m"        # Cyan
COLORS["underlineWhite"]= "\033[4;37m"       # White

# Background
COLORS["backgroundBlack"]= "\033[40m"       # Black
COLORS["backgroundRed"]= "\033[41m"         # Red
COLORS["backgroundGreen"]= "\033[42m"       # Green
COLORS["backgroundYellow"]= "\033[43m"      # Yellow
COLORS["backgroundBlue"]= "\033[44m"        # Blue
COLORS["backgroundPurple"]= "\033[45m"      # Purple
COLORS["backgroundCyan"]= "\033[46m"        # Cyan
COLORS["backgroundWhite"]= "\033[47m"       # White

# High Intensity
COLORS["intenseBlack"]= "\033[0;90m"       # Black
COLORS["intenseRed"]= "\033[0;91m"         # Red
COLORS["intenseGreen"]= "\033[0;92m"       # Green
COLORS["intenseYellow"]= "\033[0;93m"      # Yellow
COLORS["intenseBlue"]= "\033[0;94m"        # Blue
COLORS["intensePurple"]= "\033[0;95m"      # Purple
COLORS["intenseCyan"]= "\033[0;96m"        # Cyan
COLORS["intenseWhite"]= "\033[0;97m"       # White

# Bold High Intensity
COLORS["intenseBoldBlack"]= "\033[1;90m"      # Black
COLORS["intenseBoldRed"]= "\033[1;91m"        # Red
COLORS["intenseBoldGreen"]= "\033[1;92m"      # Green
COLORS["intenseBoldYellow"]= "\033[1;93m"     # Yellow
COLORS["intenseBoldBlue"]= "\033[1;94m"       # Blue
COLORS["intenseBoldPurple"]= "\033[1;95m"     # Purple
COLORS["intenseBoldCyan"]= "\033[1;96m"       # Cyan
COLORS["intenseBoldWhite"]= "\033[1;97m"      # White

# High Intensity backgrounds
COLORS["intenseBackgroundBlack"]= "\033[0;100m"   # Black
COLORS["intenseBackgroundRed"]= "\033[0;101m"     # Red
COLORS["intenseBackgroundGreen"]= "\033[0;102m"   # Green
COLORS["intenseBackgroundYellow"]= "\033[0;103m"  # Yellow
COLORS["intenseBackgroundBlue"]= "\033[0;104m"    # Blue
COLORS["intenseBackgroundPurple"]= "\033[0;105m"  # Purple
COLORS["intenseBackgroundCyan"]= "\033[0;106m"    # Cyan
COLORS["intenseBackgroundWhite"]= "\033[0;107m"   # White